# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ddopai',
                'doc_host': 'https://opimwue.github.io',
                'git_url': 'https://github.com/opimwue/ddopai',
                'lib_path': 'ddopai'},
  'syms': { 'ddopai.RL_approximators': { 'ddopai.RL_approximators.BaseApproximator': ( '60_approximators/critic_networks.html#baseapproximator',
                                                                                       'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.__init__': ( '60_approximators/critic_networks.html#baseapproximator.__init__',
                                                                                                'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.forward': ( '60_approximators/critic_networks.html#baseapproximator.forward',
                                                                                               'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.init_rnn_weights': ( '60_approximators/critic_networks.html#baseapproximator.init_rnn_weights',
                                                                                                        'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.init_weights': ( '60_approximators/critic_networks.html#baseapproximator.init_weights',
                                                                                                    'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.select_activation': ( '60_approximators/critic_networks.html#baseapproximator.select_activation',
                                                                                                         'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.select_init_method': ( '60_approximators/critic_networks.html#baseapproximator.select_init_method',
                                                                                                          'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximator.select_rnn_cell': ( '60_approximators/critic_networks.html#baseapproximator.select_rnn_cell',
                                                                                                       'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximatorMLP': ( '60_approximators/critic_networks.html#baseapproximatormlp',
                                                                                          'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximatorMLP.__init__': ( '60_approximators/critic_networks.html#baseapproximatormlp.__init__',
                                                                                                   'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximatorMLP.build_MLP': ( '60_approximators/critic_networks.html#baseapproximatormlp.build_mlp',
                                                                                                    'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximatorRNN': ( '60_approximators/critic_networks.html#baseapproximatorrnn',
                                                                                          'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximatorRNN.__init__': ( '60_approximators/critic_networks.html#baseapproximatorrnn.__init__',
                                                                                                   'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.BaseApproximatorRNN.build_RNN': ( '60_approximators/critic_networks.html#baseapproximatorrnn.build_rnn',
                                                                                                    'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPActor': ( '60_approximators/critic_networks.html#mlpactor',
                                                                               'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPActor.__init__': ( '60_approximators/critic_networks.html#mlpactor.__init__',
                                                                                        'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPActor.forward': ( '60_approximators/critic_networks.html#mlpactor.forward',
                                                                                       'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPState': ( '60_approximators/critic_networks.html#mlpstate',
                                                                               'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPState.__init__': ( '60_approximators/critic_networks.html#mlpstate.__init__',
                                                                                        'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPState.forward': ( '60_approximators/critic_networks.html#mlpstate.forward',
                                                                                       'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPStateAction': ( '60_approximators/critic_networks.html#mlpstateaction',
                                                                                     'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPStateAction.__init__': ( '60_approximators/critic_networks.html#mlpstateaction.__init__',
                                                                                              'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.MLPStateAction.forward': ( '60_approximators/critic_networks.html#mlpstateaction.forward',
                                                                                             'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNActor': ( '60_approximators/critic_networks.html#rnnactor',
                                                                               'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNActor.__init__': ( '60_approximators/critic_networks.html#rnnactor.__init__',
                                                                                        'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNActor.forward': ( '60_approximators/critic_networks.html#rnnactor.forward',
                                                                                       'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNActor.forward_with_batch': ( '60_approximators/critic_networks.html#rnnactor.forward_with_batch',
                                                                                                  'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNActor.forward_without_batch': ( '60_approximators/critic_networks.html#rnnactor.forward_without_batch',
                                                                                                     'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNMLPHybrid': ( '60_approximators/critic_networks.html#rnnmlphybrid',
                                                                                   'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNMLPHybrid.__init__': ( '60_approximators/critic_networks.html#rnnmlphybrid.__init__',
                                                                                            'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNMLPHybrid.forward': ( '60_approximators/critic_networks.html#rnnmlphybrid.forward',
                                                                                           'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNStateAction': ( '60_approximators/critic_networks.html#rnnstateaction',
                                                                                     'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNStateAction.__init__': ( '60_approximators/critic_networks.html#rnnstateaction.__init__',
                                                                                              'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNStateAction.forward': ( '60_approximators/critic_networks.html#rnnstateaction.forward',
                                                                                             'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNStateAction.forward_with_batch': ( '60_approximators/critic_networks.html#rnnstateaction.forward_with_batch',
                                                                                                        'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNStateAction.forward_without_batch': ( '60_approximators/critic_networks.html#rnnstateaction.forward_without_batch',
                                                                                                           'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNWrapper': ( '60_approximators/critic_networks.html#rnnwrapper',
                                                                                 'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNWrapper.__init__': ( '60_approximators/critic_networks.html#rnnwrapper.__init__',
                                                                                          'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNWrapper.create': ( '60_approximators/critic_networks.html#rnnwrapper.create',
                                                                                        'ddopai/RL_approximators.py'),
                                         'ddopai.RL_approximators.RNNWrapper.forward': ( '60_approximators/critic_networks.html#rnnwrapper.forward',
                                                                                         'ddopai/RL_approximators.py')},
            'ddopai.agents.base': { 'ddopai.agents.base.BaseAgent': ('40_base_agents/base_agents.html#baseagent', 'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.__init__': ( '40_base_agents/base_agents.html#baseagent.__init__',
                                                                               'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.add_batch_dim': ( '40_base_agents/base_agents.html#baseagent.add_batch_dim',
                                                                                    'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.add_obsprocessor': ( '40_base_agents/base_agents.html#baseagent.add_obsprocessor',
                                                                                       'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.convert_recursively_to_int': ( '40_base_agents/base_agents.html#baseagent.convert_recursively_to_int',
                                                                                                 'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.convert_to_numpy_array': ( '40_base_agents/base_agents.html#baseagent.convert_to_numpy_array',
                                                                                             'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.draw_action': ( '40_base_agents/base_agents.html#baseagent.draw_action',
                                                                                  'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.draw_action_': ( '40_base_agents/base_agents.html#baseagent.draw_action_',
                                                                                   'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.eval': ( '40_base_agents/base_agents.html#baseagent.eval',
                                                                           'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.load': ( '40_base_agents/base_agents.html#baseagent.load',
                                                                           'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.save': ( '40_base_agents/base_agents.html#baseagent.save',
                                                                           'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.train': ( '40_base_agents/base_agents.html#baseagent.train',
                                                                            'ddopai/agents/base.py'),
                                    'ddopai.agents.base.BaseAgent.update_model_params': ( '40_base_agents/base_agents.html#baseagent.update_model_params',
                                                                                          'ddopai/agents/base.py')},
            'ddopai.agents.basic': { 'ddopai.agents.basic.RandomAgent': ( '40_base_agents/basic_agents.html#randomagent',
                                                                          'ddopai/agents/basic.py'),
                                     'ddopai.agents.basic.RandomAgent.__init__': ( '40_base_agents/basic_agents.html#randomagent.__init__',
                                                                                   'ddopai/agents/basic.py'),
                                     'ddopai.agents.basic.RandomAgent.draw_action_': ( '40_base_agents/basic_agents.html#randomagent.draw_action_',
                                                                                       'ddopai/agents/basic.py'),
                                     'ddopai.agents.basic.RandomAgent.fit': ( '40_base_agents/basic_agents.html#randomagent.fit',
                                                                              'ddopai/agents/basic.py'),
                                     'ddopai.agents.basic.RandomAgent.load': ( '40_base_agents/basic_agents.html#randomagent.load',
                                                                               'ddopai/agents/basic.py'),
                                     'ddopai.agents.basic.RandomAgent.save': ( '40_base_agents/basic_agents.html#randomagent.save',
                                                                               'ddopai/agents/basic.py')},
            'ddopai.agents.class_names': {},
            'ddopai.agents.newsvendor.erm': { 'ddopai.agents.newsvendor.erm.BaseMetaAgent': ( '41_NV_agents/nv_erm_agents.html#basemetaagent',
                                                                                              'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.BaseMetaAgent.set_meta_dataloader': ( '41_NV_agents/nv_erm_agents.html#basemetaagent.set_meta_dataloader',
                                                                                                                  'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NVBaseAgent': ( '41_NV_agents/nv_erm_agents.html#nvbaseagent',
                                                                                            'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NVBaseAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#nvbaseagent.__init__',
                                                                                                     'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NVBaseAgent.set_loss_function': ( '41_NV_agents/nv_erm_agents.html#nvbaseagent.set_loss_function',
                                                                                                              'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendordlagent',
                                                                                                  'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendordlagent.__init__',
                                                                                                           'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLAgent.set_model': ( '41_NV_agents/nv_erm_agents.html#newsvendordlagent.set_model',
                                                                                                            'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLMetaAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendordlmetaagent',
                                                                                                      'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLMetaAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendordlmetaagent.__init__',
                                                                                                               'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLTransformerAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendordltransformeragent',
                                                                                                             'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLTransformerAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendordltransformeragent.__init__',
                                                                                                                      'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLTransformerAgent.set_model': ( '41_NV_agents/nv_erm_agents.html#newsvendordltransformeragent.set_model',
                                                                                                                       'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLTransformerMetaAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendordltransformermetaagent',
                                                                                                                 'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorDLTransformerMetaAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendordltransformermetaagent.__init__',
                                                                                                                          'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorXGBAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendorxgbagent',
                                                                                                   'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorXGBAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendorxgbagent.__init__',
                                                                                                            'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorXGBAgent.draw_action_': ( '41_NV_agents/nv_erm_agents.html#newsvendorxgbagent.draw_action_',
                                                                                                                'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorXGBAgent.fit': ( '41_NV_agents/nv_erm_agents.html#newsvendorxgbagent.fit',
                                                                                                       'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorXGBAgent.load': ( '41_NV_agents/nv_erm_agents.html#newsvendorxgbagent.load',
                                                                                                        'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorXGBAgent.save': ( '41_NV_agents/nv_erm_agents.html#newsvendorxgbagent.save',
                                                                                                        'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorlERMAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendorlermagent',
                                                                                                    'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorlERMAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendorlermagent.__init__',
                                                                                                             'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorlERMAgent.set_model': ( '41_NV_agents/nv_erm_agents.html#newsvendorlermagent.set_model',
                                                                                                              'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorlERMMetaAgent': ( '41_NV_agents/nv_erm_agents.html#newsvendorlermmetaagent',
                                                                                                        'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.NewsvendorlERMMetaAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#newsvendorlermmetaagent.__init__',
                                                                                                                 'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent',
                                                                                             'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.__init__': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.__init__',
                                                                                                      'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.draw_action_': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.draw_action_',
                                                                                                          'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.eval': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.eval',
                                                                                                  'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.fit_epoch': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.fit_epoch',
                                                                                                       'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.load': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.load',
                                                                                                  'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.predict': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.predict',
                                                                                                     'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.save': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.save',
                                                                                                  'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.set_dataloader': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.set_dataloader',
                                                                                                            'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.set_device': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.set_device',
                                                                                                        'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.set_learning_rate_scheduler': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.set_learning_rate_scheduler',
                                                                                                                         'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.set_loss_function': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.set_loss_function',
                                                                                                               'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.set_model': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.set_model',
                                                                                                       'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.set_optimizer': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.set_optimizer',
                                                                                                           'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.split_into_batches': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.split_into_batches',
                                                                                                                'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.to': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.to',
                                                                                                'ddopai/agents/newsvendor/erm.py'),
                                              'ddopai.agents.newsvendor.erm.SGDBaseAgent.train': ( '41_NV_agents/nv_erm_agents.html#sgdbaseagent.train',
                                                                                                   'ddopai/agents/newsvendor/erm.py')},
            'ddopai.agents.newsvendor.saa': { 'ddopai.agents.newsvendor.saa.BaseSAAagent': ( '41_NV_agents/nv_saa_agents.html#basesaaagent',
                                                                                             'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BaseSAAagent.__init__': ( '41_NV_agents/nv_saa_agents.html#basesaaagent.__init__',
                                                                                                      'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BaseSAAagent._validate_X_predict': ( '41_NV_agents/nv_saa_agents.html#basesaaagent._validate_x_predict',
                                                                                                                 'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BaseSAAagent.find_weighted_quantiles': ( '41_NV_agents/nv_saa_agents.html#basesaaagent.find_weighted_quantiles',
                                                                                                                     'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent',
                                                                                              'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent.__init__': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent.__init__',
                                                                                                       'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent._calc_weights': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent._calc_weights',
                                                                                                            'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent._get_fitted_model': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent._get_fitted_model',
                                                                                                                'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent.draw_action_': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent.draw_action_',
                                                                                                           'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent.fit': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent.fit',
                                                                                                  'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent.load': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent.load',
                                                                                                   'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent.predict': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent.predict',
                                                                                                      'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.BasewSAAagent.save': ( '41_NV_agents/nv_saa_agents.html#basewsaaagent.save',
                                                                                                   'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorRFwSAAagent': ( '41_NV_agents/nv_saa_agents.html#newsvendorrfwsaaagent',
                                                                                                      'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorRFwSAAagent.__init__': ( '41_NV_agents/nv_saa_agents.html#newsvendorrfwsaaagent.__init__',
                                                                                                               'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorRFwSAAagent._calc_weights': ( '41_NV_agents/nv_saa_agents.html#newsvendorrfwsaaagent._calc_weights',
                                                                                                                    'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorRFwSAAagent._get_fitted_model': ( '41_NV_agents/nv_saa_agents.html#newsvendorrfwsaaagent._get_fitted_model',
                                                                                                                        'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorSAAagent': ( '41_NV_agents/nv_saa_agents.html#newsvendorsaaagent',
                                                                                                   'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorSAAagent.__init__': ( '41_NV_agents/nv_saa_agents.html#newsvendorsaaagent.__init__',
                                                                                                            'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorSAAagent.draw_action_': ( '41_NV_agents/nv_saa_agents.html#newsvendorsaaagent.draw_action_',
                                                                                                                'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorSAAagent.fit': ( '41_NV_agents/nv_saa_agents.html#newsvendorsaaagent.fit',
                                                                                                       'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorSAAagent.load': ( '41_NV_agents/nv_saa_agents.html#newsvendorsaaagent.load',
                                                                                                        'ddopai/agents/newsvendor/saa.py'),
                                              'ddopai.agents.newsvendor.saa.NewsvendorSAAagent.save': ( '41_NV_agents/nv_saa_agents.html#newsvendorsaaagent.save',
                                                                                                        'ddopai/agents/newsvendor/saa.py')},
            'ddopai.agents.rl.mushroom_rl': { 'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent',
                                                                                                  'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.__init__': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.__init__',
                                                                                                           'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.add_batch_dimension_for_shape': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.add_batch_dimension_for_shape',
                                                                                                                                'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.add_obsprocessor': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.add_obsprocessor',
                                                                                                                   'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.draw_action_': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.draw_action_',
                                                                                                               'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.episode_start': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.episode_start',
                                                                                                                'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.eval': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.eval',
                                                                                                       'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.fit': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.fit',
                                                                                                      'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.get_input_shape': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.get_input_shape',
                                                                                                                  'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.get_loss_function': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.get_loss_function',
                                                                                                                    'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.get_optimizer_class': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.get_optimizer_class',
                                                                                                                      'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.load': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.load',
                                                                                                       'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.predict': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.predict',
                                                                                                          'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.predict_': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.predict_',
                                                                                                           'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.preprocessors': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.preprocessors',
                                                                                                                'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.save': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.save',
                                                                                                       'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.set_device': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.set_device',
                                                                                                             'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.set_model': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.set_model',
                                                                                                            'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.set_optimizer': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.set_optimizer',
                                                                                                                'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.stop': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.stop',
                                                                                                       'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.to': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.to',
                                                                                                     'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.train': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.train',
                                                                                                        'ddopai/agents/rl/mushroom_rl.py'),
                                              'ddopai.agents.rl.mushroom_rl.MushroomBaseAgent.transfer_obs_processors_to_mushroom_agent': ( '51_RL_agents/mushroom_base_agent.html#mushroombaseagent.transfer_obs_processors_to_mushroom_agent',
                                                                                                                                            'ddopai/agents/rl/mushroom_rl.py')},
            'ddopai.agents.rl.ppo': { 'ddopai.agents.rl.ppo.PPOAgent': ('51_RL_agents/ppo_agents.html#ppoagent', 'ddopai/agents/rl/ppo.py'),
                                      'ddopai.agents.rl.ppo.PPOAgent.__init__': ( '51_RL_agents/ppo_agents.html#ppoagent.__init__',
                                                                                  'ddopai/agents/rl/ppo.py'),
                                      'ddopai.agents.rl.ppo.PPOAgent.get_network_list': ( '51_RL_agents/ppo_agents.html#ppoagent.get_network_list',
                                                                                          'ddopai/agents/rl/ppo.py')},
            'ddopai.agents.rl.sac': { 'ddopai.agents.rl.sac.SACAgent': ('51_RL_agents/sac_agents.html#sacagent', 'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACAgent.__init__': ( '51_RL_agents/sac_agents.html#sacagent.__init__',
                                                                                  'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACBaseAgent': ( '51_RL_agents/sac_agents.html#sacbaseagent',
                                                                             'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACBaseAgent.__init__': ( '51_RL_agents/sac_agents.html#sacbaseagent.__init__',
                                                                                      'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACBaseAgent.get_network_list': ( '51_RL_agents/sac_agents.html#sacbaseagent.get_network_list',
                                                                                              'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACBaseAgent.predict_': ( '51_RL_agents/sac_agents.html#sacbaseagent.predict_',
                                                                                      'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACRNNAgent': ( '51_RL_agents/sac_agents.html#sacrnnagent',
                                                                            'ddopai/agents/rl/sac.py'),
                                      'ddopai.agents.rl.sac.SACRNNAgent.__init__': ( '51_RL_agents/sac_agents.html#sacrnnagent.__init__',
                                                                                     'ddopai/agents/rl/sac.py')},
            'ddopai.agents.rl.td3': { 'ddopai.agents.rl.td3.TD3Agent': ('51_RL_agents/td3_agents.html#td3agent', 'ddopai/agents/rl/td3.py'),
                                      'ddopai.agents.rl.td3.TD3Agent.__init__': ( '51_RL_agents/td3_agents.html#td3agent.__init__',
                                                                                  'ddopai/agents/rl/td3.py'),
                                      'ddopai.agents.rl.td3.TD3Agent.get_network_list': ( '51_RL_agents/td3_agents.html#td3agent.get_network_list',
                                                                                          'ddopai/agents/rl/td3.py')},
            'ddopai.approximators': { 'ddopai.approximators.BaseModule': ( '60_approximators/approximators.html#basemodule',
                                                                           'ddopai/approximators.py'),
                                      'ddopai.approximators.BaseModule.__init__': ( '60_approximators/approximators.html#basemodule.__init__',
                                                                                    'ddopai/approximators.py'),
                                      'ddopai.approximators.BaseModule.select_activation': ( '60_approximators/approximators.html#basemodule.select_activation',
                                                                                             'ddopai/approximators.py'),
                                      'ddopai.approximators.Block': ( '60_approximators/approximators.html#block',
                                                                      'ddopai/approximators.py'),
                                      'ddopai.approximators.Block.__init__': ( '60_approximators/approximators.html#block.__init__',
                                                                               'ddopai/approximators.py'),
                                      'ddopai.approximators.Block.forward': ( '60_approximators/approximators.html#block.forward',
                                                                              'ddopai/approximators.py'),
                                      'ddopai.approximators.CausalSelfAttention': ( '60_approximators/approximators.html#causalselfattention',
                                                                                    'ddopai/approximators.py'),
                                      'ddopai.approximators.CausalSelfAttention.__init__': ( '60_approximators/approximators.html#causalselfattention.__init__',
                                                                                             'ddopai/approximators.py'),
                                      'ddopai.approximators.CausalSelfAttention._init_rope': ( '60_approximators/approximators.html#causalselfattention._init_rope',
                                                                                               'ddopai/approximators.py'),
                                      'ddopai.approximators.CausalSelfAttention.forward': ( '60_approximators/approximators.html#causalselfattention.forward',
                                                                                            'ddopai/approximators.py'),
                                      'ddopai.approximators.LinearModel': ( '60_approximators/approximators.html#linearmodel',
                                                                            'ddopai/approximators.py'),
                                      'ddopai.approximators.LinearModel.__init__': ( '60_approximators/approximators.html#linearmodel.__init__',
                                                                                     'ddopai/approximators.py'),
                                      'ddopai.approximators.LinearModel.forward': ( '60_approximators/approximators.html#linearmodel.forward',
                                                                                    'ddopai/approximators.py'),
                                      'ddopai.approximators.LlamaRotaryEmbedding': ( '60_approximators/approximators.html#llamarotaryembedding',
                                                                                     'ddopai/approximators.py'),
                                      'ddopai.approximators.LlamaRotaryEmbedding.__init__': ( '60_approximators/approximators.html#llamarotaryembedding.__init__',
                                                                                              'ddopai/approximators.py'),
                                      'ddopai.approximators.LlamaRotaryEmbedding._set_cos_sin_cache': ( '60_approximators/approximators.html#llamarotaryembedding._set_cos_sin_cache',
                                                                                                        'ddopai/approximators.py'),
                                      'ddopai.approximators.LlamaRotaryEmbedding.forward': ( '60_approximators/approximators.html#llamarotaryembedding.forward',
                                                                                             'ddopai/approximators.py'),
                                      'ddopai.approximators.MLP': ('60_approximators/approximators.html#mlp', 'ddopai/approximators.py'),
                                      'ddopai.approximators.MLP.__init__': ( '60_approximators/approximators.html#mlp.__init__',
                                                                             'ddopai/approximators.py'),
                                      'ddopai.approximators.MLP.forward': ( '60_approximators/approximators.html#mlp.forward',
                                                                            'ddopai/approximators.py'),
                                      'ddopai.approximators.MLP_block': ( '60_approximators/approximators.html#mlp_block',
                                                                          'ddopai/approximators.py'),
                                      'ddopai.approximators.MLP_block.__init__': ( '60_approximators/approximators.html#mlp_block.__init__',
                                                                                   'ddopai/approximators.py'),
                                      'ddopai.approximators.MLP_block.forward': ( '60_approximators/approximators.html#mlp_block.forward',
                                                                                  'ddopai/approximators.py'),
                                      'ddopai.approximators.RMSNorm': ( '60_approximators/approximators.html#rmsnorm',
                                                                        'ddopai/approximators.py'),
                                      'ddopai.approximators.RMSNorm.__init__': ( '60_approximators/approximators.html#rmsnorm.__init__',
                                                                                 'ddopai/approximators.py'),
                                      'ddopai.approximators.RMSNorm.forward': ( '60_approximators/approximators.html#rmsnorm.forward',
                                                                                'ddopai/approximators.py'),
                                      'ddopai.approximators.Transformer': ( '60_approximators/approximators.html#transformer',
                                                                            'ddopai/approximators.py'),
                                      'ddopai.approximators.Transformer.__init__': ( '60_approximators/approximators.html#transformer.__init__',
                                                                                     'ddopai/approximators.py'),
                                      'ddopai.approximators.Transformer.forward': ( '60_approximators/approximators.html#transformer.forward',
                                                                                    'ddopai/approximators.py'),
                                      'ddopai.approximators.apply_rotary_pos_emb': ( '60_approximators/approximators.html#apply_rotary_pos_emb',
                                                                                     'ddopai/approximators.py'),
                                      'ddopai.approximators.find_multiple': ( '60_approximators/approximators.html#find_multiple',
                                                                              'ddopai/approximators.py'),
                                      'ddopai.approximators.rotate_half': ( '60_approximators/approximators.html#rotate_half',
                                                                            'ddopai/approximators.py')},
            'ddopai.dataloaders.base': { 'ddopai.dataloaders.base.BaseDataLoader': ( '10_dataloaders/base_dataloader.html#basedataloader',
                                                                                     'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.X_shape': ( '10_dataloaders/base_dataloader.html#basedataloader.x_shape',
                                                                                             'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.Y_shape': ( '10_dataloaders/base_dataloader.html#basedataloader.y_shape',
                                                                                             'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.__getitem__': ( '10_dataloaders/base_dataloader.html#basedataloader.__getitem__',
                                                                                                 'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.__init__': ( '10_dataloaders/base_dataloader.html#basedataloader.__init__',
                                                                                              'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.__len__': ( '10_dataloaders/base_dataloader.html#basedataloader.__len__',
                                                                                             'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.get_all_X': ( '10_dataloaders/base_dataloader.html#basedataloader.get_all_x',
                                                                                               'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.get_all_Y': ( '10_dataloaders/base_dataloader.html#basedataloader.get_all_y',
                                                                                               'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.len_test': ( '10_dataloaders/base_dataloader.html#basedataloader.len_test',
                                                                                              'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.len_train': ( '10_dataloaders/base_dataloader.html#basedataloader.len_train',
                                                                                               'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.len_val': ( '10_dataloaders/base_dataloader.html#basedataloader.len_val',
                                                                                             'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.test': ( '10_dataloaders/base_dataloader.html#basedataloader.test',
                                                                                          'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.train': ( '10_dataloaders/base_dataloader.html#basedataloader.train',
                                                                                           'ddopai/dataloaders/base.py'),
                                         'ddopai.dataloaders.base.BaseDataLoader.val': ( '10_dataloaders/base_dataloader.html#basedataloader.val',
                                                                                         'ddopai/dataloaders/base.py')},
            'ddopai.dataloaders.distribution': { 'ddopai.dataloaders.distribution.BaseDistributionDataLoader': ( '10_dataloaders/distribution_loaders.html#basedistributiondataloader',
                                                                                                                 'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.BaseDistributionDataLoader.__init__': ( '10_dataloaders/distribution_loaders.html#basedistributiondataloader.__init__',
                                                                                                                          'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader',
                                                                                                                   'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.X_shape': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.x_shape',
                                                                                                                           'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.Y_shape': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.y_shape',
                                                                                                                           'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.__getitem__': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.__getitem__',
                                                                                                                               'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.__init__': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.__init__',
                                                                                                                            'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.__len__': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.__len__',
                                                                                                                           'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.get_all_X': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.get_all_x',
                                                                                                                             'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.get_all_Y': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.get_all_y',
                                                                                                                             'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.len_test': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.len_test',
                                                                                                                            'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.len_train': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.len_train',
                                                                                                                             'ddopai/dataloaders/distribution.py'),
                                                 'ddopai.dataloaders.distribution.NormalDistributionDataLoader.len_val': ( '10_dataloaders/distribution_loaders.html#normaldistributiondataloader.len_val',
                                                                                                                           'ddopai/dataloaders/distribution.py')},
            'ddopai.dataloaders.tabular': { 'ddopai.dataloaders.tabular.MultiShapeLoader': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader',
                                                                                             'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.X_shape': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.x_shape',
                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.Y_shape': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.y_shape',
                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.__getitem__': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.__getitem__',
                                                                                                         'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.__init__': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.__init__',
                                                                                                      'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.__len__': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.__len__',
                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.build_engineered_SKU_features': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.build_engineered_sku_features',
                                                                                                                           'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.get_all_X': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.get_all_x',
                                                                                                       'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.get_all_Y': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.get_all_y',
                                                                                                       'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.get_time_SKU_idx': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.get_time_sku_idx',
                                                                                                              'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.identify_train_SKUs': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.identify_train_skus',
                                                                                                                 'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.is_one_hot': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.is_one_hot',
                                                                                                        'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.is_one_hot_across_skus': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.is_one_hot_across_skus',
                                                                                                                    'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.len_test': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.len_test',
                                                                                                      'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.len_train': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.len_train',
                                                                                                       'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.len_val': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.len_val',
                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.normalize_demand_and_features_in_sample': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.normalize_demand_and_features_in_sample',
                                                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.normalize_demand_and_features_out_of_sample': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.normalize_demand_and_features_out_of_sample',
                                                                                                                                         'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.save_indices': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.save_indices',
                                                                                                          'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.set_in_sample_val_test_SKUs': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.set_in_sample_val_test_skus',
                                                                                                                         'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.set_out_of_sample_SKUs': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.set_out_of_sample_skus',
                                                                                                                    'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.set_return_sku': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.set_return_sku',
                                                                                                            'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.set_train_subset': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.set_train_subset',
                                                                                                              'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.test_out_of_sample_SKUs': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.test_out_of_sample_skus',
                                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.MultiShapeLoader.update_lag_features': ( '10_dataloaders/tabular_dataloaders.html#multishapeloader.update_lag_features',
                                                                                                                 'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader': ( '10_dataloaders/tabular_dataloaders.html#xydataloader',
                                                                                         'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.X_shape': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.x_shape',
                                                                                                 'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.Y_shape': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.y_shape',
                                                                                                 'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.__getitem__': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.__getitem__',
                                                                                                     'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.__init__': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.__init__',
                                                                                                  'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.__len__': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.__len__',
                                                                                                 'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.get_all_X': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.get_all_x',
                                                                                                   'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.get_all_Y': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.get_all_y',
                                                                                                   'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.len_test': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.len_test',
                                                                                                  'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.len_train': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.len_train',
                                                                                                   'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.len_val': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.len_val',
                                                                                                 'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.normalize_features': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.normalize_features',
                                                                                                            'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.prep_lag_features': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.prep_lag_features',
                                                                                                           'ddopai/dataloaders/tabular.py'),
                                            'ddopai.dataloaders.tabular.XYDataLoader.update_lag_features': ( '10_dataloaders/tabular_dataloaders.html#xydataloader.update_lag_features',
                                                                                                             'ddopai/dataloaders/tabular.py')},
            'ddopai.datasets.default_datasets': { 'ddopai.datasets.default_datasets.DatasetLoader': ( '80_datasets/default_datasets.html#datasetloader',
                                                                                                      'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.DatasetLoader.__init__': ( '80_datasets/default_datasets.html#datasetloader.__init__',
                                                                                                               'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.DatasetLoader.load_dataset': ( '80_datasets/default_datasets.html#datasetloader.load_dataset',
                                                                                                                   'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.DatasetLoader.show_dataset_types': ( '80_datasets/default_datasets.html#datasetloader.show_dataset_types',
                                                                                                                         'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.download_file_from_github': ( '80_datasets/default_datasets.html#download_file_from_github',
                                                                                                                  'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.get_all_release_tags': ( '80_datasets/default_datasets.html#get_all_release_tags',
                                                                                                             'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.get_asset_url': ( '80_datasets/default_datasets.html#get_asset_url',
                                                                                                      'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.get_dataset_url': ( '80_datasets/default_datasets.html#get_dataset_url',
                                                                                                        'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.get_release_tag': ( '80_datasets/default_datasets.html#get_release_tag',
                                                                                                        'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.load_data_from_directory': ( '80_datasets/default_datasets.html#load_data_from_directory',
                                                                                                                 'ddopai/datasets/default_datasets.py'),
                                                  'ddopai.datasets.default_datasets.unzip_file': ( '80_datasets/default_datasets.html#unzip_file',
                                                                                                   'ddopai/datasets/default_datasets.py')},
            'ddopai.datasets.kaggle_m5': { 'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader',
                                                                                                'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.__init__': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.__init__',
                                                                                                         'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.check_data_path': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.check_data_path',
                                                                                                                'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.create_paths': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.create_paths',
                                                                                                             'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.download_data': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.download_data',
                                                                                                              'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.import_from_folder': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.import_from_folder',
                                                                                                                   'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.load_dataset': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.load_dataset',
                                                                                                             'ddopai/datasets/kaggle_m5.py'),
                                           'ddopai.datasets.kaggle_m5.KaggleM5DatasetLoader.preprocess_pipeline': ( '80_datasets/kaggle_m5.html#kagglem5datasetloader.preprocess_pipeline',
                                                                                                                    'ddopai/datasets/kaggle_m5.py')},
            'ddopai.envs.base': { 'ddopai.envs.base.BaseEnvironment': ('20_base_env/base_env.html#baseenvironment', 'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.__init__': ( '20_base_env/base_env.html#baseenvironment.__init__',
                                                                                 'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.add_postprocessor': ( '20_base_env/base_env.html#baseenvironment.add_postprocessor',
                                                                                          'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.get_observation': ( '20_base_env/base_env.html#baseenvironment.get_observation',
                                                                                        'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.get_start_index': ( '20_base_env/base_env.html#baseenvironment.get_start_index',
                                                                                        'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.info': ( '20_base_env/base_env.html#baseenvironment.info',
                                                                             'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.mdp_info': ( '20_base_env/base_env.html#baseenvironment.mdp_info',
                                                                                 'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.mode': ( '20_base_env/base_env.html#baseenvironment.mode',
                                                                             'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.reset': ( '20_base_env/base_env.html#baseenvironment.reset',
                                                                              'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.reset_index': ( '20_base_env/base_env.html#baseenvironment.reset_index',
                                                                                    'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.return_truncation_handler': ( '20_base_env/base_env.html#baseenvironment.return_truncation_handler',
                                                                                                  'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.set_action_space': ( '20_base_env/base_env.html#baseenvironment.set_action_space',
                                                                                         'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.set_index': ( '20_base_env/base_env.html#baseenvironment.set_index',
                                                                                  'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.set_observation_space': ( '20_base_env/base_env.html#baseenvironment.set_observation_space',
                                                                                              'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.set_param': ( '20_base_env/base_env.html#baseenvironment.set_param',
                                                                                  'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.set_return_truncation': ( '20_base_env/base_env.html#baseenvironment.set_return_truncation',
                                                                                              'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.step': ( '20_base_env/base_env.html#baseenvironment.step',
                                                                             'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.step_': ( '20_base_env/base_env.html#baseenvironment.step_',
                                                                              'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.stop': ( '20_base_env/base_env.html#baseenvironment.stop',
                                                                             'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.test': ( '20_base_env/base_env.html#baseenvironment.test',
                                                                             'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.train': ( '20_base_env/base_env.html#baseenvironment.train',
                                                                              'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.update_mdp_info': ( '20_base_env/base_env.html#baseenvironment.update_mdp_info',
                                                                                        'ddopai/envs/base.py'),
                                  'ddopai.envs.base.BaseEnvironment.val': ( '20_base_env/base_env.html#baseenvironment.val',
                                                                            'ddopai/envs/base.py')},
            'ddopai.envs.inventory.base': { 'ddopai.envs.inventory.base.BaseInventoryEnv': ( '21_envs_inventory/base_inventory_env.html#baseinventoryenv',
                                                                                             'ddopai/envs/inventory/base.py'),
                                            'ddopai.envs.inventory.base.BaseInventoryEnv.__init__': ( '21_envs_inventory/base_inventory_env.html#baseinventoryenv.__init__',
                                                                                                      'ddopai/envs/inventory/base.py'),
                                            'ddopai.envs.inventory.base.BaseInventoryEnv.get_observation': ( '21_envs_inventory/base_inventory_env.html#baseinventoryenv.get_observation',
                                                                                                             'ddopai/envs/inventory/base.py'),
                                            'ddopai.envs.inventory.base.BaseInventoryEnv.reset': ( '21_envs_inventory/base_inventory_env.html#baseinventoryenv.reset',
                                                                                                   'ddopai/envs/inventory/base.py'),
                                            'ddopai.envs.inventory.base.BaseInventoryEnv.set_action_space': ( '21_envs_inventory/base_inventory_env.html#baseinventoryenv.set_action_space',
                                                                                                              'ddopai/envs/inventory/base.py'),
                                            'ddopai.envs.inventory.base.BaseInventoryEnv.set_observation_space': ( '21_envs_inventory/base_inventory_env.html#baseinventoryenv.set_observation_space',
                                                                                                                   'ddopai/envs/inventory/base.py')},
            'ddopai.envs.inventory.inventory_utils': { 'ddopai.envs.inventory.inventory_utils.OrderPipeline': ( '21_envs_inventory/inventory_utils.html#orderpipeline',
                                                                                                                'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.__init__': ( '21_envs_inventory/inventory_utils.html#orderpipeline.__init__',
                                                                                                                         'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.check_max_min_mean_lt': ( '21_envs_inventory/inventory_utils.html#orderpipeline.check_max_min_mean_lt',
                                                                                                                                      'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.check_stochasticity': ( '21_envs_inventory/inventory_utils.html#orderpipeline.check_stochasticity',
                                                                                                                                    'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.draw_lead_times': ( '21_envs_inventory/inventory_utils.html#orderpipeline.draw_lead_times',
                                                                                                                                'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.get_orders_arriving': ( '21_envs_inventory/inventory_utils.html#orderpipeline.get_orders_arriving',
                                                                                                                                    'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.get_pipeline': ( '21_envs_inventory/inventory_utils.html#orderpipeline.get_pipeline',
                                                                                                                             'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.reset': ( '21_envs_inventory/inventory_utils.html#orderpipeline.reset',
                                                                                                                      'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.set_param': ( '21_envs_inventory/inventory_utils.html#orderpipeline.set_param',
                                                                                                                          'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.shape': ( '21_envs_inventory/inventory_utils.html#orderpipeline.shape',
                                                                                                                      'ddopai/envs/inventory/inventory_utils.py'),
                                                       'ddopai.envs.inventory.inventory_utils.OrderPipeline.step': ( '21_envs_inventory/inventory_utils.html#orderpipeline.step',
                                                                                                                     'ddopai/envs/inventory/inventory_utils.py')},
            'ddopai.envs.inventory.multi_period': { 'ddopai.envs.inventory.multi_period.MultiPeriodEnv': ( '21_envs_inventory/multi_period_envs.html#multiperiodenv',
                                                                                                           'ddopai/envs/inventory/multi_period.py'),
                                                    'ddopai.envs.inventory.multi_period.MultiPeriodEnv.__init__': ( '21_envs_inventory/multi_period_envs.html#multiperiodenv.__init__',
                                                                                                                    'ddopai/envs/inventory/multi_period.py'),
                                                    'ddopai.envs.inventory.multi_period.MultiPeriodEnv.get_observation': ( '21_envs_inventory/multi_period_envs.html#multiperiodenv.get_observation',
                                                                                                                           'ddopai/envs/inventory/multi_period.py'),
                                                    'ddopai.envs.inventory.multi_period.MultiPeriodEnv.reset': ( '21_envs_inventory/multi_period_envs.html#multiperiodenv.reset',
                                                                                                                 'ddopai/envs/inventory/multi_period.py'),
                                                    'ddopai.envs.inventory.multi_period.MultiPeriodEnv.set_observation_space': ( '21_envs_inventory/multi_period_envs.html#multiperiodenv.set_observation_space',
                                                                                                                                 'ddopai/envs/inventory/multi_period.py'),
                                                    'ddopai.envs.inventory.multi_period.MultiPeriodEnv.step_': ( '21_envs_inventory/multi_period_envs.html#multiperiodenv.step_',
                                                                                                                 'ddopai/envs/inventory/multi_period.py')},
            'ddopai.envs.inventory.single_period': { 'ddopai.envs.inventory.single_period.NewsvendorEnv': ( '21_envs_inventory/single_period_envs.html#newsvendorenv',
                                                                                                            'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnv.__init__': ( '21_envs_inventory/single_period_envs.html#newsvendorenv.__init__',
                                                                                                                     'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnv.determine_cost': ( '21_envs_inventory/single_period_envs.html#newsvendorenv.determine_cost',
                                                                                                                           'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnv.step_': ( '21_envs_inventory/single_period_envs.html#newsvendorenv.step_',
                                                                                                                  'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnv.update_cu_co': ( '21_envs_inventory/single_period_envs.html#newsvendorenv.update_cu_co',
                                                                                                                         'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl',
                                                                                                                      'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.__init__': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.__init__',
                                                                                                                               'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.check_evaluation_metric': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.check_evaluation_metric',
                                                                                                                                              'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.check_sl_distribution': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.check_sl_distribution',
                                                                                                                                            'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.determine_cost': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.determine_cost',
                                                                                                                                     'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.draw_parameter': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.draw_parameter',
                                                                                                                                     'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.get_observation': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.get_observation',
                                                                                                                                      'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.set_observation_space': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.set_observation_space',
                                                                                                                                            'ddopai/envs/inventory/single_period.py'),
                                                     'ddopai.envs.inventory.single_period.NewsvendorEnvVariableSL.set_val_test_sl': ( '21_envs_inventory/single_period_envs.html#newsvendorenvvariablesl.set_val_test_sl',
                                                                                                                                      'ddopai/envs/inventory/single_period.py')},
            'ddopai.experiment_functions': { 'ddopai.experiment_functions.EarlyStoppingHandler': ( '30_experiment_functions/experiment_functions.html#earlystoppinghandler',
                                                                                                   'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.EarlyStoppingHandler.__init__': ( '30_experiment_functions/experiment_functions.html#earlystoppinghandler.__init__',
                                                                                                            'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.EarlyStoppingHandler.add_result': ( '30_experiment_functions/experiment_functions.html#earlystoppinghandler.add_result',
                                                                                                              'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.calculate_score': ( '30_experiment_functions/experiment_functions.html#calculate_score',
                                                                                              'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.log_info': ( '30_experiment_functions/experiment_functions.html#log_info',
                                                                                       'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.run_experiment': ( '30_experiment_functions/experiment_functions.html#run_experiment',
                                                                                             'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.run_test_episode': ( '30_experiment_functions/experiment_functions.html#run_test_episode',
                                                                                               'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.save_agent': ( '30_experiment_functions/experiment_functions.html#save_agent',
                                                                                         'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.test_agent': ( '30_experiment_functions/experiment_functions.html#test_agent',
                                                                                         'ddopai/experiment_functions.py'),
                                             'ddopai.experiment_functions.update_best': ( '30_experiment_functions/experiment_functions.html#update_best',
                                                                                          'ddopai/experiment_functions.py')},
            'ddopai.loss_functions': { 'ddopai.loss_functions.pinball_loss': ( '00_utils/loss_functions.html#pinball_loss',
                                                                               'ddopai/loss_functions.py'),
                                       'ddopai.loss_functions.quantile_loss': ( '00_utils/loss_functions.html#quantile_loss',
                                                                                'ddopai/loss_functions.py')},
            'ddopai.meta_experiment_functions': { 'ddopai.meta_experiment_functions.clean_up': ( '30_experiment_functions/meta_experiment_functions.html#clean_up',
                                                                                                 'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.download_data': ( '30_experiment_functions/meta_experiment_functions.html#download_data',
                                                                                                      'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.get_ddop_data': ( '30_experiment_functions/meta_experiment_functions.html#get_ddop_data',
                                                                                                      'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.import_config': ( '30_experiment_functions/meta_experiment_functions.html#import_config',
                                                                                                      'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.init_wandb': ( '30_experiment_functions/meta_experiment_functions.html#init_wandb',
                                                                                                   'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.merge_with_namespace': ( '30_experiment_functions/meta_experiment_functions.html#merge_with_namespace',
                                                                                                             'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.prep_and_run_test': ( '30_experiment_functions/meta_experiment_functions.html#prep_and_run_test',
                                                                                                          'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.prep_experiment': ( '30_experiment_functions/meta_experiment_functions.html#prep_experiment',
                                                                                                        'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.select_agent': ( '30_experiment_functions/meta_experiment_functions.html#select_agent',
                                                                                                     'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.set_indices': ( '30_experiment_functions/meta_experiment_functions.html#set_indices',
                                                                                                    'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.set_up_earlystoppinghandler': ( '30_experiment_functions/meta_experiment_functions.html#set_up_earlystoppinghandler',
                                                                                                                    'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.set_up_env': ( '30_experiment_functions/meta_experiment_functions.html#set_up_env',
                                                                                                   'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.set_warnings': ( '30_experiment_functions/meta_experiment_functions.html#set_warnings',
                                                                                                     'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.track_libraries_and_git': ( '30_experiment_functions/meta_experiment_functions.html#track_libraries_and_git',
                                                                                                                'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.transfer_additional_target_to_env': ( '30_experiment_functions/meta_experiment_functions.html#transfer_additional_target_to_env',
                                                                                                                          'ddopai/meta_experiment_functions.py'),
                                                  'ddopai.meta_experiment_functions.transfer_lag_window_to_env': ( '30_experiment_functions/meta_experiment_functions.html#transfer_lag_window_to_env',
                                                                                                                   'ddopai/meta_experiment_functions.py')},
            'ddopai.ml_utils': { 'ddopai.ml_utils.LRSchedulerPerStep': ('00_utils/ml_utils.html#lrschedulerperstep', 'ddopai/ml_utils.py'),
                                 'ddopai.ml_utils.LRSchedulerPerStep.__init__': ( '00_utils/ml_utils.html#lrschedulerperstep.__init__',
                                                                                  'ddopai/ml_utils.py'),
                                 'ddopai.ml_utils.LRSchedulerPerStep.step': ( '00_utils/ml_utils.html#lrschedulerperstep.step',
                                                                              'ddopai/ml_utils.py')},
            'ddopai.obsprocessors': { 'ddopai.obsprocessors.AddParamsToFeatures': ( '00_utils/obsprocessors.html#addparamstofeatures',
                                                                                    'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.AddParamsToFeatures.__call__': ( '00_utils/obsprocessors.html#addparamstofeatures.__call__',
                                                                                             'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.AddParamsToFeatures.__init__': ( '00_utils/obsprocessors.html#addparamstofeatures.__init__',
                                                                                             'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.AddParamsToFeaturesLEGACY': ( '00_utils/obsprocessors.html#addparamstofeatureslegacy',
                                                                                          'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.AddParamsToFeaturesLEGACY.__call__': ( '00_utils/obsprocessors.html#addparamstofeatureslegacy.__call__',
                                                                                                   'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.AddParamsToFeaturesLEGACY.__init__': ( '00_utils/obsprocessors.html#addparamstofeatureslegacy.__init__',
                                                                                                   'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.BaseProcessor': ( '00_utils/obsprocessors.html#baseprocessor',
                                                                              'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.BaseProcessor.determine_output_shape': ( '00_utils/obsprocessors.html#baseprocessor.determine_output_shape',
                                                                                                     'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.ConvertDictSpace': ( '00_utils/obsprocessors.html#convertdictspace',
                                                                                 'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.ConvertDictSpace.__call__': ( '00_utils/obsprocessors.html#convertdictspace.__call__',
                                                                                          'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.ConvertDictSpace.__init__': ( '00_utils/obsprocessors.html#convertdictspace.__init__',
                                                                                          'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.FlattenTimeDimNumpy': ( '00_utils/obsprocessors.html#flattentimedimnumpy',
                                                                                    'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.FlattenTimeDimNumpy.__call__': ( '00_utils/obsprocessors.html#flattentimedimnumpy.__call__',
                                                                                             'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.FlattenTimeDimNumpy.__init__': ( '00_utils/obsprocessors.html#flattentimedimnumpy.__init__',
                                                                                             'ddopai/obsprocessors.py'),
                                      'ddopai.obsprocessors.FlattenTimeDimNumpy.check_input': ( '00_utils/obsprocessors.html#flattentimedimnumpy.check_input',
                                                                                                'ddopai/obsprocessors.py')},
            'ddopai.postprocessors': { 'ddopai.postprocessors.ClipAction': ( '00_utils/postprocessors.html#clipaction',
                                                                             'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.ClipAction.__call__': ( '00_utils/postprocessors.html#clipaction.__call__',
                                                                                      'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.ClipAction.__init__': ( '00_utils/postprocessors.html#clipaction.__init__',
                                                                                      'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.ClipAction._convert_to_array': ( '00_utils/postprocessors.html#clipaction._convert_to_array',
                                                                                               'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.MoveBatchToProductDim': ( '00_utils/postprocessors.html#movebatchtoproductdim',
                                                                                        'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.MoveBatchToProductDim.__call__': ( '00_utils/postprocessors.html#movebatchtoproductdim.__call__',
                                                                                                 'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.MoveBatchToProductDim.__init__': ( '00_utils/postprocessors.html#movebatchtoproductdim.__init__',
                                                                                                 'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.RoundAction': ( '00_utils/postprocessors.html#roundaction',
                                                                              'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.RoundAction.__call__': ( '00_utils/postprocessors.html#roundaction.__call__',
                                                                                       'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.RoundAction.__init__': ( '00_utils/postprocessors.html#roundaction.__init__',
                                                                                       'ddopai/postprocessors.py'),
                                       'ddopai.postprocessors.RoundAction._validate_unit_size': ( '00_utils/postprocessors.html#roundaction._validate_unit_size',
                                                                                                  'ddopai/postprocessors.py')},
            'ddopai.torch_utils.loss_functions': { 'ddopai.torch_utils.loss_functions.TorchPinballLoss': ( '00_utils/torch_loss_functions.html#torchpinballloss',
                                                                                                           'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchPinballLoss.__init__': ( '00_utils/torch_loss_functions.html#torchpinballloss.__init__',
                                                                                                                    'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchPinballLoss.convert_cost_param': ( '00_utils/torch_loss_functions.html#torchpinballloss.convert_cost_param',
                                                                                                                              'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchPinballLoss.forward': ( '00_utils/torch_loss_functions.html#torchpinballloss.forward',
                                                                                                                   'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchQuantileLoss': ( '00_utils/torch_loss_functions.html#torchquantileloss',
                                                                                                            'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchQuantileLoss.__init__': ( '00_utils/torch_loss_functions.html#torchquantileloss.__init__',
                                                                                                                     'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchQuantileLoss.convert_quantile': ( '00_utils/torch_loss_functions.html#torchquantileloss.convert_quantile',
                                                                                                                             'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.TorchQuantileLoss.forward': ( '00_utils/torch_loss_functions.html#torchquantileloss.forward',
                                                                                                                    'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.pinball_loss': ( '00_utils/torch_loss_functions.html#pinball_loss',
                                                                                                       'ddopai/torch_utils/loss_functions.py'),
                                                   'ddopai.torch_utils.loss_functions.quantile_loss': ( '00_utils/torch_loss_functions.html#quantile_loss',
                                                                                                        'ddopai/torch_utils/loss_functions.py')},
            'ddopai.tracking': { 'ddopai.tracking.get_git_hash': ('00_utils/tracking.html#get_git_hash', 'ddopai/tracking.py'),
                                 'ddopai.tracking.get_library_version': ( '00_utils/tracking.html#get_library_version',
                                                                          'ddopai/tracking.py')},
            'ddopai.utils': { 'ddopai.utils.DatasetWrapper': ('00_utils/utils.html#datasetwrapper', 'ddopai/utils.py'),
                              'ddopai.utils.DatasetWrapper.__getitem__': ( '00_utils/utils.html#datasetwrapper.__getitem__',
                                                                           'ddopai/utils.py'),
                              'ddopai.utils.DatasetWrapper.__init__': ('00_utils/utils.html#datasetwrapper.__init__', 'ddopai/utils.py'),
                              'ddopai.utils.DatasetWrapper.__len__': ('00_utils/utils.html#datasetwrapper.__len__', 'ddopai/utils.py'),
                              'ddopai.utils.DatasetWrapperMeta': ('00_utils/utils.html#datasetwrappermeta', 'ddopai/utils.py'),
                              'ddopai.utils.DatasetWrapperMeta.__getitem__': ( '00_utils/utils.html#datasetwrappermeta.__getitem__',
                                                                               'ddopai/utils.py'),
                              'ddopai.utils.DatasetWrapperMeta.__init__': ( '00_utils/utils.html#datasetwrappermeta.__init__',
                                                                            'ddopai/utils.py'),
                              'ddopai.utils.MDPInfo': ('00_utils/utils.html#mdpinfo', 'ddopai/utils.py'),
                              'ddopai.utils.MDPInfo.__init__': ('00_utils/utils.html#mdpinfo.__init__', 'ddopai/utils.py'),
                              'ddopai.utils.MDPInfo.shape': ('00_utils/utils.html#mdpinfo.shape', 'ddopai/utils.py'),
                              'ddopai.utils.MDPInfo.size': ('00_utils/utils.html#mdpinfo.size', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter': ('00_utils/utils.html#parameter', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter.__call__': ('00_utils/utils.html#parameter.__call__', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter.__init__': ('00_utils/utils.html#parameter.__init__', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter.get_value': ('00_utils/utils.html#parameter.get_value', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter.set_value': ('00_utils/utils.html#parameter.set_value', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter.shape': ('00_utils/utils.html#parameter.shape', 'ddopai/utils.py'),
                              'ddopai.utils.Parameter.size': ('00_utils/utils.html#parameter.size', 'ddopai/utils.py'),
                              'ddopai.utils.check_parameter_types': ('00_utils/utils.html#check_parameter_types', 'ddopai/utils.py'),
                              'ddopai.utils.merge_dictionaries': ('00_utils/utils.html#merge_dictionaries', 'ddopai/utils.py'),
                              'ddopai.utils.set_param': ('00_utils/utils.html#set_param', 'ddopai/utils.py')}}}



"""Some helper functions for machine learning tasks."""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_utils/40_ml_utils.ipynb.

# %% auto 0
__all__ = ['LRSchedulerPerStep']

# %% ../nbs/00_utils/40_ml_utils.ipynb 3
from typing import  List, Tuple, Literal
import torch

# %% ../nbs/00_utils/40_ml_utils.ipynb 4
class LRSchedulerPerStep():
    """
    Learning rate scheduler from Attention is all you need paper (https://arxiv.org/abs/1706.03762)
    One ajustment: Added base LR as tunable parameter rather than setting it automated based on model dimension
    """
    
    def __init__(self,
                optimizer: torch.optim.Optimizer, # Optimizer to adjust learning rate for
                base_learning_rate: float = 0.0001,
                warmup: int =4000):

        # Ensure optimizer is a PyTorch optimizer
        if not isinstance(optimizer, torch.optim.Optimizer):
            raise ValueError('Optimizer must be a PyTorch optimizer')
        
        self.optimizer = optimizer
        self.basic = base_learning_rate
        self.warm = warmup**-1.5
        self.scaling_factor = 1/warmup**-0.5 # ensures that the peak realtive to the base lr is always 1

        self.step_num = 0   
        self.step()
        
    def step(self):
        self.step_num += 1
        lr = self.basic * self.scaling_factor * min(self.step_num**-0.5, self.step_num*self.warm)
        
        for param_group in self.optimizer.param_groups:
            param_group['lr'] = lr
